@@ -58,11 +58,11 @@ struct XSParseInfixHooks {
   bool (*permit) (pTHX_ void *hookdata);
 
   /* These hooks are alternatives; the first one defined is used */
-  OP *(*new_op)(pTHX_ U32 flags, OP *lhs, OP *rhs, ANY *parsedata, void *hookdata);
+  OP *(*new_op)(pTHX_ U32 flags, OP *lhs, OP *rhs, SV **parsedata, void *hookdata);
   OP *(*ppaddr)(pTHX); /* A pp func used directly in newBINOP_custom() */
 
   /* optional */
-  void (*parse)(pTHX_ U32 flags, ANY *parsedata, void *hookdata);
+  void (*parse)(pTHX_ U32 flags, SV **parsedata, void *hookdata);
 };
 
 struct XSParseInfixInfo {
@@ -73,6 +73,18 @@ struct XSParseInfixInfo {
   void *hookdata;
 };
 
+static bool (*parse_infix_func)(pTHX_ enum XSParseInfixSelection select, struct XSParseInfixInfo **infop);
+#define parse_infix(select, infop) S_parse_infix(aTHX_ select, infop)
+static bool S_parse_infix(pTHX_ enum XSParseInfixSelection select, struct XSParseInfixInfo **infop)
+{
+  if(!parse_infix_func)
+    croak("Must call boot_xs_parse_infix() first");
+
+  struct XSParseInfixInfo *infocopy;
+
+  return (*parse_infix_func)(aTHX_ select, infop);
+}
+
 static OP *(*xs_parse_infix_new_op_func)(pTHX_ const struct XSParseInfixInfo *info, U32 flags, OP *lhs, OP *rhs);
 #define xs_parse_infix_new_op(info, flags, lhs, rhs)  S_xs_parse_infix_new_op(aTHX_ info, flags, lhs, rhs)
 static OP *S_xs_parse_infix_new_op(pTHX_ const struct XSParseInfixInfo *info, U32 flags, OP *lhs, OP *rhs)
@@ -115,6 +127,8 @@ static void S_boot_xs_parse_infix(pTHX_ double ver) {
     croak("XS::Parse::Infix ABI version mismatch - library supports <= %d, compiled for %d",
         abi_ver, XSPARSEINFIX_ABI_VERSION);
 
+  parse_infix_func = INT2PTR(bool (*)(pTHX_ enum XSParseInfixSelection, struct XSParseInfixInfo **),
+      SvUV(*hv_fetchs(PL_modglobal, "XS::Parse::Infix/parse()@2", 0)));
   xs_parse_infix_new_op_func = INT2PTR(OP *(*)(pTHX_ const struct XSParseInfixInfo *, U32, OP *, OP *),
       SvUV(*hv_fetchs(PL_modglobal, "XS::Parse::Infix/new_op()@0", 0)));
   register_xs_parse_infix_func = INT2PTR(void (*)(pTHX_ const char *, const struct XSParseInfixHooks *, void *),
