@@ -3,7 +3,7 @@
 #
 #  (C) Paul Evans, 2021-2022 -- leonerd@leonerd.org.uk
 
-package XS::Parse::Infix 0.26;
+package XS::Parse::Infix 0.27;
 
 use v5.14;
 use warnings;
@@ -68,6 +68,15 @@ requirement; e.g.
 
    boot_xs_parse_infix(0.14);
 
+=head2 parse_infix
+
+   bool parse_infix(enum XSParseInfixSelection select, struct XSParseInfixInfo **infop);
+
+This function attempts to parse syntax for an infix operator from the current
+parser position. If it is successful, it fills in the variable pointed to by
+I<infop> with a pointer to the actual information structure and returns
+C<true>. If no suitable operator is found, returns C<false>.
+
 =head2 xs_parse_infix_new_op
 
    OP *xs_parse_infix_new_op(const struct XSParseInfixInfo *info, U32 flags,
@@ -79,7 +88,7 @@ perl's C<newBINOP> function.
 
 The C<info> structure pointer would be obtained from the C<infix> field of the
 result of invoking the various C<XPK_INFIX_*> token types from
-C<XS::Parse::Keyword>.
+C<XS::Parse::Keyword>, or by calling L</parse_infix> directly.
 
 =head2 register_xs_parse_infix
 
@@ -88,8 +97,8 @@ C<XS::Parse::Keyword>.
 
 This function installs a set of parsing hooks to be associated with the given
 operator name. This new operator will then be available via
-L<XS::Parse::Keyword> by the various C<XPK_INFIX_*> token types, or to core
-perl's C<PL_infix_plugin> if availble.
+L<XS::Parse::Keyword> by the various C<XPK_INFIX_*> token types,
+L</parse_infix>, or to core perl's C<PL_infix_plugin> if available.
 
 These tokens will all yield an info structure, with the following fields:
 
