@@ -13,6 +13,7 @@
 #include "infix.h"
 
 #include "perl-backcompat.c.inc"
+#include "optree-additions.c.inc"
 
 #include "force_list_keeping_pushmark.c.inc"
 #include "make_argcheck_ops.c.inc"
@@ -146,7 +147,7 @@ struct Registration {
 
 static struct Registration *registrations;
 
-static OP *new_op(pTHX_ const struct HooksAndData hd, U32 flags, OP *lhs, OP *rhs, ANY *parsedata)
+static OP *new_op(pTHX_ const struct HooksAndData hd, U32 flags, OP *lhs, OP *rhs, SV **parsedata)
 {
   if(hd.hooks->new_op) {
     if(hd.hooks->flags & (1<<15)) {
@@ -233,14 +234,14 @@ static OP *S_unwrap_list(pTHX_ OP *o, bool may_unwrap_anonlist)
 
 #ifdef HAVE_PL_INFIX_PLUGIN
 
-void parse(pTHX_ ANY *parsedata, struct Perl_custom_infix *def)
+void parse(pTHX_ SV **parsedata, struct Perl_custom_infix *def)
 {
   struct Registration *reg = (struct Registration *)def;
 
   (*reg->hd.hooks->parse)(aTHX_ 0, parsedata, reg->hd.data);
 }
 
-OP *build_op(pTHX_ ANY *parsedata, OP *lhs, OP *rhs, struct Perl_custom_infix *def)
+OP *build_op(pTHX_ SV **parsedata, OP *lhs, OP *rhs, struct Perl_custom_infix *def)
 {
   struct Registration *reg = (struct Registration *)def;
 
@@ -478,14 +479,6 @@ static OP *ckcall_wrapper_func_listlist(pTHX_ OP *op, GV *namegv, SV *ckobj)
       NULL);
 }
 
-#define newSLUGOP(idx)  S_newSLUGOP(aTHX_ idx)
-static OP *S_newSLUGOP(pTHX_ int idx)
-{
-  OP *op = newGVOP(OP_AELEMFAST, 0, PL_defgv);
-  op->op_private = idx;
-  return op;
-}
-
 static void make_wrapper_func(pTHX_ const struct HooksAndData *hd)
 {
   SV *funcname = newSVpvn(hd->hooks->wrapper_func_name, strlen(hd->hooks->wrapper_func_name));
@@ -845,11 +838,6 @@ void XSParseInfix_boot(pTHX)
   ));
 
 #ifdef HAVE_PL_INFIX_PLUGIN
-  OP_CHECK_MUTEX_LOCK;
-  if(!next_infix_plugin) {
-    next_infix_plugin = PL_infix_plugin;
-    PL_infix_plugin = &my_infix_plugin;
-  }
-  OP_CHECK_MUTEX_UNLOCK;
+  wrap_infix_plugin(&my_infix_plugin, &next_infix_plugin);
 #endif
 }
